==> cmr-client-0.1.0-20170826.214733-2.jar: public/js/cmr/client/util.js <==
// Compiled by ClojureScript 1.9.908 {}
goog.provide('cmr.client.util');
goog.require('cljs.core');
goog.require('cmr.client.constants');
cmr.client.util.parse_endpoint = (function cmr$client$util$parse_endpoint(endpoint,endpoints){
if(typeof endpoint === 'string'){
return endpoint;
} else {
var G__20254 = endpoint;
var G__20254__$1 = (((G__20254 instanceof cljs.core.Keyword))?G__20254.fqn:null);
switch (G__20254__$1) {
case "prod":
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(cmr.client.constants.host_prod),cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"service","service",-1963054559).cljs$core$IFn$_invoke$arity$1(endpoints))].join('');

break;
case "uat":
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(cmr.client.constants.host_uat),cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"service","service",-1963054559).cljs$core$IFn$_invoke$arity$1(endpoints))].join('');

break;
case "sit":
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(cmr.client.constants.host_sit),cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"service","service",-1963054559).cljs$core$IFn$_invoke$arity$1(endpoints))].join('');

break;
case "local":
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(cmr.client.constants.host_local),cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"local","local",-1497766724).cljs$core$IFn$_invoke$arity$1(endpoints))].join('');

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__20254__$1)].join('')));

}
}
});

//# sourceMappingURL=util.js.map

==> cmr-client-0.2.0-20171003.163915-8.jar: public/js/cmr/client/util.js <==
// Compiled by ClojureScript 1.9.908 {}
goog.provide('cmr.client.util');
goog.require('cljs.core');
goog.require('cmr.client.constants');
cmr.client.util.parse_endpoint = (function cmr$client$util$parse_endpoint(endpoint,endpoints){
if(typeof endpoint === 'string'){
return endpoint;
} else {
var G__29891 = endpoint;
var G__29891__$1 = (((G__29891 instanceof cljs.core.Keyword))?G__29891.fqn:null);
switch (G__29891__$1) {
case "prod":
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(cmr.client.constants.host_prod),cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"service","service",-1963054559).cljs$core$IFn$_invoke$arity$1(endpoints))].join('');

break;
case "uat":
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(cmr.client.constants.host_uat),cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"service","service",-1963054559).cljs$core$IFn$_invoke$arity$1(endpoints))].join('');

break;
case "sit":
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(cmr.client.constants.host_sit),cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"service","service",-1963054559).cljs$core$IFn$_invoke$arity$1(endpoints))].join('');

break;
case "local":
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(cmr.client.constants.host_local),cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"local","local",-1497766724).cljs$core$IFn$_invoke$arity$1(endpoints))].join('');

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__29891__$1)].join('')));

}
}
});
cmr.client.util.read_json_str = (function cmr$client$util$read_json_str(string_data){
return cljs.core.js__GT_clj.call(null,string_data);
});

//# sourceMappingURL=util.js.map?rel=1503637915547
